==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosReplaceActionsFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodHttpChaosReplaceActionsFluentImpl<A extends PodHttpChaosReplaceActionsFluent<A>> extends BaseFluent<A> implements PodHttpChaosReplaceActionsFluent<A>{
  public PodHttpChaosReplaceActionsFluentImpl() {
  }
  public PodHttpChaosReplaceActionsFluentImpl(PodHttpChaosReplaceActions instance) {
    this.withBody(instance.getBody()); 
    this.withCode(instance.getCode()); 
    this.withHeaders(instance.getHeaders()); 
    this.withMethod(instance.getMethod()); 
    this.withPath(instance.getPath()); 
    this.withQueries(instance.getQueries()); 
  }
  private String body;
  private Integer code;
  private Map<String,String> headers;
  private String method;
  private String path;
  private Map<String,String> queries;
  public String getBody() {
    return this.body;
  }
  public A withBody(String body) {
    this.body=body; return (A) this;
  }
  public Boolean hasBody() {
    return this.body != null;
  }
  public Integer getCode() {
    return this.code;
  }
  public A withCode(Integer code) {
    this.code=code; return (A) this;
  }
  public Boolean hasCode() {
    return this.code != null;
  }
  public A addToHeaders(String key,String value) {
    if(this.headers == null && key != null && value != null) { this.headers = new LinkedHashMap(); }
    if(key != null && value != null) {this.headers.put(key, value);} return (A)this;
  }
  public A addToHeaders(Map<String,String> map) {
    if(this.headers == null && map != null) { this.headers = new LinkedHashMap(); }
    if(map != null) { this.headers.putAll(map);} return (A)this;
  }
  public A removeFromHeaders(String key) {
    if(this.headers == null) { return (A) this; }
    if(key != null && this.headers != null) {this.headers.remove(key);} return (A)this;
  }
  public A removeFromHeaders(Map<String,String> map) {
    if(this.headers == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.headers != null){this.headers.remove(key);}}} return (A)this;
  }
  public Map<String,String> getHeaders() {
    return this.headers;
  }
  public <K,V>A withHeaders(Map<String,String> headers) {
    if (headers == null) { this.headers =  null;} else {this.headers = new LinkedHashMap(headers);} return (A) this;
  }
  public Boolean hasHeaders() {
    return this.headers != null;
  }
  public String getMethod() {
    return this.method;
  }
  public A withMethod(String method) {
    this.method=method; return (A) this;
  }
  public Boolean hasMethod() {
    return this.method != null;
  }
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  public A addToQueries(String key,String value) {
    if(this.queries == null && key != null && value != null) { this.queries = new LinkedHashMap(); }
    if(key != null && value != null) {this.queries.put(key, value);} return (A)this;
  }
  public A addToQueries(Map<String,String> map) {
    if(this.queries == null && map != null) { this.queries = new LinkedHashMap(); }
    if(map != null) { this.queries.putAll(map);} return (A)this;
  }
  public A removeFromQueries(String key) {
    if(this.queries == null) { return (A) this; }
    if(key != null && this.queries != null) {this.queries.remove(key);} return (A)this;
  }
  public A removeFromQueries(Map<String,String> map) {
    if(this.queries == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.queries != null){this.queries.remove(key);}}} return (A)this;
  }
  public Map<String,String> getQueries() {
    return this.queries;
  }
  public <K,V>A withQueries(Map<String,String> queries) {
    if (queries == null) { this.queries =  null;} else {this.queries = new LinkedHashMap(queries);} return (A) this;
  }
  public Boolean hasQueries() {
    return this.queries != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodHttpChaosReplaceActionsFluentImpl that = (PodHttpChaosReplaceActionsFluentImpl) o;
    if (body != null ? !body.equals(that.body) :that.body != null) return false;
    if (code != null ? !code.equals(that.code) :that.code != null) return false;
    if (headers != null ? !headers.equals(that.headers) :that.headers != null) return false;
    if (method != null ? !method.equals(that.method) :that.method != null) return false;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (queries != null ? !queries.equals(that.queries) :that.queries != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(body,  code,  headers,  method,  path,  queries,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (body != null) { sb.append("body:"); sb.append(body + ","); }
    if (code != null) { sb.append("code:"); sb.append(code + ","); }
    if (headers != null && !headers.isEmpty()) { sb.append("headers:"); sb.append(headers + ","); }
    if (method != null) { sb.append("method:"); sb.append(method + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (queries != null && !queries.isEmpty()) { sb.append("queries:"); sb.append(queries); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosReplaceActionsFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodHttpChaosReplaceActionsFluentImpl<A extends PodHttpChaosReplaceActionsFluent<A>> extends BaseFluent<A> implements PodHttpChaosReplaceActionsFluent<A>{
  public PodHttpChaosReplaceActionsFluentImpl() {
  }
  public PodHttpChaosReplaceActionsFluentImpl(PodHttpChaosReplaceActions instance) {
    if (instance != null) {
      this.withBody(instance.getBody());
      this.withCode(instance.getCode());
      this.withHeaders(instance.getHeaders());
      this.withMethod(instance.getMethod());
      this.withPath(instance.getPath());
      this.withQueries(instance.getQueries());
    }
  }
  private String body;
  private Integer code;
  private Map<String,String> headers;
  private String method;
  private String path;
  private Map<String,String> queries;
  public String getBody() {
    return this.body;
  }
  public A withBody(String body) {
    this.body=body; return (A) this;
  }
  public Boolean hasBody() {
    return this.body != null;
  }
  public Integer getCode() {
    return this.code;
  }
  public A withCode(Integer code) {
    this.code=code; return (A) this;
  }
  public Boolean hasCode() {
    return this.code != null;
  }
  public A addToHeaders(String key,String value) {
    if(this.headers == null && key != null && value != null) { this.headers = new LinkedHashMap(); }
    if(key != null && value != null) {this.headers.put(key, value);} return (A)this;
  }
  public A addToHeaders(Map<String,String> map) {
    if(this.headers == null && map != null) { this.headers = new LinkedHashMap(); }
    if(map != null) { this.headers.putAll(map);} return (A)this;
  }
  public A removeFromHeaders(String key) {
    if(this.headers == null) { return (A) this; }
    if(key != null && this.headers != null) {this.headers.remove(key);} return (A)this;
  }
  public A removeFromHeaders(Map<String,String> map) {
    if(this.headers == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.headers != null){this.headers.remove(key);}}} return (A)this;
  }
  public Map<String,String> getHeaders() {
    return this.headers;
  }
  public <K,V>A withHeaders(Map<String,String> headers) {
    if (headers == null) { this.headers =  null;} else {this.headers = new LinkedHashMap(headers);} return (A) this;
  }
  public Boolean hasHeaders() {
    return this.headers != null;
  }
  public String getMethod() {
    return this.method;
  }
  public A withMethod(String method) {
    this.method=method; return (A) this;
  }
  public Boolean hasMethod() {
    return this.method != null;
  }
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  public A addToQueries(String key,String value) {
    if(this.queries == null && key != null && value != null) { this.queries = new LinkedHashMap(); }
    if(key != null && value != null) {this.queries.put(key, value);} return (A)this;
  }
  public A addToQueries(Map<String,String> map) {
    if(this.queries == null && map != null) { this.queries = new LinkedHashMap(); }
    if(map != null) { this.queries.putAll(map);} return (A)this;
  }
  public A removeFromQueries(String key) {
    if(this.queries == null) { return (A) this; }
    if(key != null && this.queries != null) {this.queries.remove(key);} return (A)this;
  }
  public A removeFromQueries(Map<String,String> map) {
    if(this.queries == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.queries != null){this.queries.remove(key);}}} return (A)this;
  }
  public Map<String,String> getQueries() {
    return this.queries;
  }
  public <K,V>A withQueries(Map<String,String> queries) {
    if (queries == null) { this.queries =  null;} else {this.queries = new LinkedHashMap(queries);} return (A) this;
  }
  public Boolean hasQueries() {
    return this.queries != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodHttpChaosReplaceActionsFluentImpl that = (PodHttpChaosReplaceActionsFluentImpl) o;
    if (!java.util.Objects.equals(body, that.body)) return false;

    if (!java.util.Objects.equals(code, that.code)) return false;

    if (!java.util.Objects.equals(headers, that.headers)) return false;

    if (!java.util.Objects.equals(method, that.method)) return false;

    if (!java.util.Objects.equals(path, that.path)) return false;

    if (!java.util.Objects.equals(queries, that.queries)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(body,  code,  headers,  method,  path,  queries,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (body != null) { sb.append("body:"); sb.append(body + ","); }
    if (code != null) { sb.append("code:"); sb.append(code + ","); }
    if (headers != null && !headers.isEmpty()) { sb.append("headers:"); sb.append(headers + ","); }
    if (method != null) { sb.append("method:"); sb.append(method + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (queries != null && !queries.isEmpty()) { sb.append("queries:"); sb.append(queries); }
    sb.append("}");
    return sb.toString();
  }
  
}
